package com.sky.common.interceptor;

import com.sky.common.constant.JwtClaimsConstant;
import com.sky.common.context.BaseContext;
import com.sky.common.properties.JwtProperties;
import com.sky.common.utils.JwtUtil;
import io.jsonwebtoken.Claims;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Component;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 管理端用户判断
 */
@Component
@RequiredArgsConstructor
@Slf4j
public class JwtTokenAdminInterceptor implements HandlerInterceptor {
    private final JwtProperties jwtProperties;

    public boolean preHandle(@NotNull HttpServletRequest request, @NotNull HttpServletResponse response, @NotNull Object handler) {
        // 判断当前兰街道的是Controller的方法还是其它资源
        if (!(handler instanceof HandlerMethod)) {
            // 拦截到的不是动态方法，直接放行
            return true;
        }
        // 1. 从请求头中获取令牌
        String token = request.getHeader(jwtProperties.getAdminTokenName());

        // 2. 拦截令牌
        log.info("jwt校验：{}", token);

        try {
            Claims claims = JwtUtil.parseJWT(jwtProperties.getAdminSecretKey(), token);
            Long empId = Long.valueOf(claims.get(JwtClaimsConstant.EMP_ID).toString());
            log.info("当前员工ID：{}", empId);
            // 3. 通过放行
            BaseContext.setUserId(empId);
            return true;
        } catch (Exception exception) {
            response.setStatus(401);
            return false;
        }
    }
}
