package com.sky.service;

import com.sky.common.result.PageResult;
import com.sky.pojo.dto.SetmealDTO;
import com.sky.pojo.dto.SetmealPageQueryDTO;
import com.sky.pojo.entity.Setmeal;
import com.sky.pojo.vo.DishItemVO;
import com.sky.pojo.vo.SetmealVO;

import java.util.List;

public interface SetmealService {

    /**
     * 分页查询
     *
     * @param dto 前端请求
     * @return PageResult
     */
    PageResult<SetmealVO> pageQuery(SetmealPageQueryDTO dto);

    /**
     * 根据id查询套餐
     *
     * @param id 套餐id
     * @return 套餐相关信息
     */
    SetmealVO page4Id(Long id);

    /**
     * 修改套餐
     *
     * @param dto 前端请求
     */
    void update(SetmealDTO dto);

    /**
     * 新增套餐
     *
     * @param setmealDTO 套餐信息
     */
    void insert(SetmealDTO setmealDTO);

    /**
     * 套餐起售、停售
     *
     * @param status 状态
     * @param id     id
     */
    void updateStatus(Integer status, Long id);

    /**
     * 批量删除套餐
     *
     * @param ids 要删除套餐ids
     */
    void delete(List<Long> ids);

    /**
     * 条件查询
     *
     * @param setmeal 套餐
     * @return List<Setmeal>
     */
    List<Setmeal> list(Setmeal setmeal);

    /**
     * 根据id查询菜品选项
     *
     * @param id id
     * @return List<DishItemVO>
     */
    List<DishItemVO> getDishItemById(Long id);
}
